@@ -78,6 +78,7 @@ class Worker:
         delete_work_dir_on_exit=False,  # type: bool
         # A flag indicating if the worker will exit if it encounters an exception
         exit_on_exception=False,  # type: bool
+        shared_memory_size_gb=1,  # type: int
     ):
         self.image_manager = image_manager
         self.dependency_manager = dependency_manager
@@ -131,6 +132,7 @@ class Worker:
             upload_bundle_callback=self.upload_bundle_contents,
             assign_cpu_and_gpu_sets_fn=self.assign_cpu_and_gpu_sets,
             shared_file_system=self.shared_file_system,
+            shared_memory_size_gb=shared_memory_size_gb,
         )
 
     def init_docker_networks(self, docker_network_prefix, verbose=True):
